@@ -1,5 +1,5 @@
 <?php
-// $Id: block.tpl.php,v 1.1 2009/06/07 22:19:37 nbz Exp $
+// $Id: block.tpl.php,v 1.2 2010/02/17 04:54:42 nbz Exp $
 
 /**
  * @file block.tpl.php
@@ -27,8 +27,8 @@
  */
 ?>
 <div id="block-<?php print $block->module .'-'. $block->delta; ?>" class="block block-<?php print $block->module .' '.$zebra; ?>">
-<?php if ($block->subject): ?>
-  <h3><?php print $block->subject ?></h3>
+<?php if ($block->subject && $block->region != 'menu_region'): ?>
+  <h2><?php print $block->subject ?></h2>
 <?php endif;?>
 
   <div class="content">
